API — D-SCRIPT v1.0-beta documentation

# API

- dscript.commands
  - dscript.commands.embed
  - dscript.commands.train
  - dscript.commands.eval
  - dscript.commands.predict
- dscript.models
  - dscript.models.embedding
  - dscript.models.contact
  - dscript.models.interaction

## dscript.alphabets

## dscript.fasta

`dscript.fasta.` `parse`(f, comment='#')

  Parse a file in `.fasta` format.

  Parameters

    - f (_io.TextIOWrapper) – Input file object

    - comment (str) – Character used for comments

  Returns

    names, sequence

  Return type

    list[str], list[str]

`dscript.fasta.` `parse_directory`(directory, extension='.seq')

  Parse all files in a directory ending with `extension`.

  Parameters

    - directory (str) – Input directory

    - extension (str) – Extension of all files to read in

  Returns

    names, sequence

  Return type

    list[str], list[str]

`dscript.fasta.` `write`(nam, seq, f)

  Write a file in `.fasta` format.

  Parameters

    - nam (list[str]) – List of names

    - seq (list[str]) – List of sequences

    - f (_io.TextIOWrapper) – Output file object

## dscript.language_model

## dscript.pretrained

## dscript.utils